==> pegasus-merchandise-api-3.11.2-GS-20240902.084414-1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/ProductOnshelfSortVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;

public class ProductOnshelfSortVO implements Serializable {
    private Integer id;

    private Long productId;

    private String productCode;

    private Integer sort;

    private Integer sourceSort;

    private String channelCode;

    private String groupName;

    private Date createTime;

    private Date updateTime;

    private Integer createId;

    private String createMan;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode == null ? null : productCode.trim();
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Integer getSourceSort() {
        return sourceSort;
    }

    public void setSourceSort(Integer sourceSort) {
        this.sourceSort = sourceSort;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode == null ? null : channelCode.trim();
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName == null ? null : groupName.trim();
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan == null ? null : createMan.trim();
    }
}

==> pegasus-merchandise-api-4.0.1-GS-20250625.110323-3-sources.jar: com/thebeastshop/pegasus/merchandise/vo/ProductOnshelfSortVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;

public class ProductOnshelfSortVO implements Serializable {
    private Integer id;

    private Long productId;

    private String productCode;

    private Integer sort;

    private Integer sourceSort;

    private String channelCode;

    private String groupName;

    private Date createTime;

    private Date updateTime;

    private Integer createId;

    private String createMan;

    private Date saleProdCreateTime;
    private Boolean hasDel;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode == null ? null : productCode.trim();
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Integer getSourceSort() {
        return sourceSort;
    }

    public void setSourceSort(Integer sourceSort) {
        this.sourceSort = sourceSort;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode == null ? null : channelCode.trim();
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName == null ? null : groupName.trim();
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan == null ? null : createMan.trim();
    }

    public Date getSaleProdCreateTime() {
        return saleProdCreateTime;
    }

    public void setSaleProdCreateTime(Date saleProdCreateTime) {
        this.saleProdCreateTime = saleProdCreateTime;
    }

    public Boolean getHasDel() {
        return hasDel;
    }

    public void setHasDel(Boolean hasDel) {
        this.hasDel = hasDel;
    }

}
